@@ -140,12 +140,25 @@ class Ui_MainWindow(QMainWindow):
         else:  ALL_OPTS="-sound 1 "
         if self.gui_opts["fs"] == "false":
 		ALL_OPTS = ALL_OPTS + "-fs 0 "
-        else:  ALL_OPT= ALL_OPTS + "-fs 1 "
+        else:  ALL_OPTS= ALL_OPTS + "-fs 1 "
+        if self.gui_opts["game_genie"] == "false":
+		ALL_OPTS = ALL_OPTS + "-gg 0 "
+        else:  ALL_OPTS= ALL_OPTS + "-gg 1 "
+        if self.gui_opts["tv_blur"] == "false":
+        	if self.gui_opts["fs"] == "false":
+			ALL_OPTS = ALL_OPTS + "-efx 0"
+		else:
+			ALL_OPTS = ALL_OPTS + "-efxfs 0"
+	else:
+        	if self.gui_opts["fs"] == "false":
+			ALL_OPTS = ALL_OPTS + "-efx 2"
+		else:
+			ALL_OPTS = ALL_OPTS + "-efxfs 2"
 	ALL_OPTS = ALL_OPTS + "-bpp " + self.gui_opts["bpp"] + " "
 
 	if not (self.gameFile == "No roms found" ):
 		# we can't do multiple commands in startDetached
-		print self.gui_opts["exec_path"] + "/fceu "+ALL_OPTS+ " " +self.gameFile
+		print self.gui_opts["exec_path"] + "/fceu "+ALL_OPTS+ " " + '"' + self.gui_opts["rom_path"] + "/" + self.gameFile +  '"'
 		QProcess.startDetached(self.gui_opts["exec_path"] + "/fceu "+ALL_OPTS+ " " + '"' + self.gui_opts["rom_path"] + "/" + self.gameFile + '"' )
 
 		if (self.gui_opts["exit_after_launch"] == "true"):
@@ -226,6 +239,28 @@ class ConfigWindow(QMainWindow):
         grid.addWidget(self.exitPushButton,0,2)
 	if self.gui_opts["exit_after_launch"] == "true":
 		self.exitPushButton.setChecked(True)
+	# GameGenie
+        self.ggPushButton = QPushButton("GameGenie",self)
+	self.ggPushButton.setCheckable(True)
+        grid.addWidget(self.ggPushButton,1,0)
+	if os.path.exists(Home + "/.fceultra/gg.rom"):
+		if self.gui_opts["game_genie"] == "true":
+			self.ggPushButton.setChecked(True)
+		else:
+			self.ggPushButton.setChecked(False)
+	else:
+		self.ggPushButton.setEnabled(False)
+	# TV Blur
+        self.blurPushButton = QPushButton("TV blur",self)
+	self.blurPushButton.setCheckable(True)
+        grid.addWidget(self.blurPushButton,1,1)
+	if self.gui_opts["bpp"] == "8":
+		self.blurPushButton.setEnabled(False)
+	else:
+		if self.gui_opts["tv_blur"] == "true":
+			self.blurPushButton.setChecked(True)
+		else:
+			self.blurPushButton.setChecked(False)
 	# BPP
 	grid.addWidget(QLabel("<center>Bits per pixel (fs):</center>"), 3, 0)
         self.comboBPP = QComboBox(self)
@@ -283,6 +318,12 @@ class ConfigWindow(QMainWindow):
         if self.exitPushButton.isChecked():
            self.gui_opts["exit_after_launch"] = "true"
         else: self.gui_opts["exit_after_launch"] = "false" 
+        if self.ggPushButton.isChecked():
+           self.gui_opts["game_genie"] = "true"
+        else: self.gui_opts["game_genie"] = "false" 
+        if self.blurPushButton.isChecked():
+           self.gui_opts["tv_blur"] = "true"
+        else: self.gui_opts["tv_blur"] = "false" 
 	self.gui_opts["bpp"] = self.comboBPP.currentText()
         if RomPath != "":
            self.gui_opts["rom_path"] = RomPath
