@@ -11,6 +11,8 @@ then
 	echo "sound true" >> $CFG_FILE
 	echo "bpp 16" >> $CFG_FILE
 	echo "fs true" >> $CFG_FILE
+	echo "game_genie false" >> $CFG_FILE
+	echo "tv_blur false" >> $CFG_FILE
 fi
 # Set missing values
 grep ^exec_path $CFG_FILE >/dev/null || echo "exec_path /usr/bin" >> $CFG_FILE
@@ -19,6 +21,8 @@ grep ^rom_path $CFG_FILE >/dev/null || echo "rom_path notset" >> $CFG_FILE
 grep ^sound $CFG_FILE >/dev/null || echo "sound true" >> $CFG_FILE
 grep ^bpp $CFG_FILE >/dev/null || echo "bpp 16" >> $CFG_FILE
 grep ^fs $CFG_FILE >/dev/null || echo "fs true" >> $CFG_FILE
+grep ^game_genie $CFG_FILE >/dev/null || echo "game_genie false" >> $CFG_FILE
+grep ^tv_blur $CFG_FILE >/dev/null || echo "tv_blur false" >> $CFG_FILE
  
 cd /opt/fceu-gui/
 python fceu-gui.py
